@@ -1,6 +1,7 @@
 from airzone.utils import *
 import logging
 from enum import Enum
+from array import array
 
 class MachineOperationMode(Enum):
     STOP = 0
@@ -90,8 +91,10 @@ def change_bit_value(state, address, bit, value):
     else:
         ch = '0'
     temp = format(state[address], '016b')
-    temp[len(temp)-1-bit] = ch
-    return int(temp, 2)
+    temp1 = array('c', temp)
+    idx = len(temp)-1-bit
+    temp1[idx] = ch
+    return int(temp1.tostring(), 2)
 
 def date_as_number(date):
     l = bitfield(date.weekday() + 1)
